/* Automatically generated by mksystem from config.h; do not edit. */

/* This header contains information obtained by INN at configure time that
   is needed by INN headers.  Autoconf results that may conflict with the
   autoconf results of another package have INN_ prepended to the
   preprocessor symbols. */

#ifndef INN_SYSTEM_H
#define INN_SYSTEM_H 1

#define INN_HAVE_C99_VAMACROS 1
#define INN_HAVE_DECL_INET_ATON 1
#define INN_HAVE_DECL_INET_NTOA 1
#define INN_HAVE_GETADDRINFO 1
#define INN_HAVE_GETADDRINFO_ADDRCONFIG 1
#define INN_HAVE_GETNAMEINFO 1
#define INN_HAVE_GNU_VAMACROS 1
#define INN_HAVE_INET6 1
#define INN_HAVE_INET_ATON 1
#define INN_HAVE_INET_NTOA 1
#define INN_HAVE_INET_NTOP 1
#define INN_HAVE_INTTYPES_H 1
#define INN_HAVE_LONG_LONG_INT 1
#define INN_HAVE_MSYNC_3_ARG 1
#define INN_HAVE_SOCKLEN_T 1
#define INN_HAVE_STDBOOL_H 1
#define INN_HAVE_STRUCT_SOCKADDR_STORAGE 1
#define INN_HAVE_STRUCT_SOCKADDR_STORAGE_SS_FAMILY 1
#define INN_HAVE_SYS_BITYPES_H 1
#define INN_HAVE_UNIX_DOMAIN_SOCKETS 1
#define INN_HAVE__BOOL 1

#endif /* INN_SYSTEM_H */
